==> postgres-check-api-0.0.2.tgz: package/schema.ts <==
import { OAS } from '@codeaim/api-schema';
import {
  OpenApiSpecificationBuilder,
  SchemaBuilder,
} from '@codeaim/api-schema/build/schema-type';

const schemas = SchemaBuilder.create()
  .add('Collection', (s) =>
    s.object(
      {
        totalItems: s.number(),
      },
      {
        view: s.object({
          next: s.string(),
        }),
      },
    ),
  )
  .add('Account', (s) =>
    s.object({
      email: s.string(),
      apiKey: s.string(),
    }),
  )
  .add('Database', (s) =>
    s.object({
      id: s.string(),
      name: s.string(),
    }),
  )
  .add('Monitor', (s) =>
    s.object({
      id: s.string(),
      account: s.string(),
      name: s.string(),
      connectionString: s.string(),
      created: s.string(),
    }),
  )
  .add('MonitorCollection', (s) =>
    s.allOf(
      s.reference('Collection'),
      s.object({
        member: s.array(s.reference('Monitor')),
      }),
    ),
  )
  .add('Query', (s) =>
    s.object({
      id: s.string(),
      type: s.string(),
      account: s.string(),
      check: s.string(),
      userId: s.string(),
      databaseId: s.string(),
      query: s.string(),
      value: s.oneOf(s.string(), s.number()),
    }),
  )
  .add('QueryCollection', (s) =>
    s.allOf(
      s.reference('Collection'),
      s.object({
        member: s.array(s.reference('Query')),
      }),
    ),
  )
  .add('Check', (s) =>
    s.object({
      id: s.string(),
      account: s.string(),
      monitor: s.string(),
      created: s.string(),
      databases: s.array(s.reference('Database')),
      connections: s.object({}, {}, true),
      totalConnections: s.number(),
      queryCount: s.number(),
      totalCalls: s.number(),
      totalExecutionTime: s.number(),
      totalConsumedIo: s.number(),
      totalRows: s.number(),
      totalLongRunningTransactions: s.number(),
    }),
  )
  .add('CheckCollection', (s) =>
    s.allOf(
      s.reference('Collection'),
      s.object({
        member: s.array(s.reference('Check')),
      }),
    ),
  )
  .build();

const postgresCheckApi: OAS = OpenApiSpecificationBuilder.create(schemas, {
  title: 'Postgres Check Api',
  version: '0.0.0',
})
  .addComponent('responses', (o) => ({
    BadRequest: o.response(o.textContent()),
    Unauthorized: o.response(o.textContent()),
    Forbidden: o.response(o.textContent()),
    InternalServerError: o.response(o.textContent()),
  }))
  .addComponent('securitySchemes', (o) => ({
    ApiKey: o.apiKeyScheme('header', 'x-api-key'),
  }))
  .defaultResponses((o) => ({
    400: o.responseReference('BadRequest'),
    401: o.responseReference('Unauthorized'),
    403: o.responseReference('Forbidden'),
    500: o.responseReference('InternalServerError'),
  }))
  .add('security', (o) => [{ ApiKey: [] }])
  .add('paths', (o) => ({
    '/monitor': {
      get: {
        operationId: 'getMonitors',
        parameters: [],
        responses: {
          200: o.response(o.jsonContent('MonitorCollection')),
        },
      },
      post: {
        operationId: 'createMonitor',
        parameters: [],
        requestBody: {
          content: o.jsonContent('Monitor'),
        },
        responses: {
          201: o.response(o.jsonContent('Monitor')),
        },
      },
    },
    '/monitor/{monitorId}/check': {
      get: {
        operationId: 'getChecks',
        parameters: [
          o.path('monitorId'),
          o.query('created', false),
          o.query('limit', false),
          o.query('next', false),
        ],
        responses: {
          200: o.response(o.jsonContent('CheckCollection')),
        },
      },
    },
    '/monitor/{monitorId}/check/{checkId}/query': {
      get: {
        operationId: 'getQueries',
        parameters: [
          o.path('monitorId'),
          o.path('checkId'),
          o.query('type'),
          o.query('created', false),
          o.query('limit', false),
          o.query('next', false),
        ],
        responses: {
          200: o.response(o.jsonContent('QueryCollection')),
        },
      },
    },
  }))
  .add('servers', (o) => [
    { url: 'http://localhost:5001', description: 'local', variables: {} },
  ])
  .build();

export default postgresCheckApi;

==> postgres-check-api-0.0.4.tgz: package/schema.ts <==
import { OAS } from '@codeaim/api-schema';
import {
  OpenApiSpecificationBuilder,
  SchemaBuilder,
} from '@codeaim/api-schema/build/schema-type';

const schemas = SchemaBuilder.create()
  .add('Collection', (s) =>
    s.object(
      {
        totalItems: s.number(),
      },
      {
        view: s.object({
          next: s.string(),
        }),
      },
    ),
  )
  .add('Account', (s) =>
    s.object({
      email: s.string(),
      apiKey: s.string(),
    }),
  )
  .add('Database', (s) =>
    s.object({
      id: s.string(),
      name: s.string(),
    }),
  )
  .add('Monitor', (s) =>
    s.object({
      id: s.string(),
      account: s.string(),
      name: s.string(),
      connectionString: s.string(),
      created: s.string(),
    }),
  )
  .add('MonitorCollection', (s) =>
    s.allOf(
      s.reference('Collection'),
      s.object({
        member: s.array(s.reference('Monitor')),
      }),
    ),
  )
  .add('Query', (s) =>
    s.object({
      id: s.string(),
      type: s.string(),
      account: s.string(),
      check: s.string(),
      userId: s.string(),
      databaseId: s.string(),
      query: s.string(),
      value: s.oneOf(s.string(), s.number()),
    }),
  )
  .add('QueryCollection', (s) =>
    s.allOf(
      s.reference('Collection'),
      s.object({
        member: s.array(s.reference('Query')),
      }),
    ),
  )
  .add('Check', (s) =>
    s.object({
      id: s.string(),
      account: s.string(),
      monitor: s.string(),
      created: s.string(),
      databases: s.array(s.reference('Database')),
      connections: s.object({}, {}, true),
      totalConnections: s.number(),
      queryCount: s.number(),
      totalCalls: s.number(),
      totalExecutionTime: s.number(),
      totalConsumedIo: s.number(),
      totalRows: s.number(),
      totalLongRunningTransactions: s.number(),
    }),
  )
  .add('CheckCollection', (s) =>
    s.allOf(
      s.reference('Collection'),
      s.object({
        member: s.array(s.reference('Check')),
      }),
    ),
  )
  .build();

const postgresCheckApi: OAS = OpenApiSpecificationBuilder.create(schemas, {
  title: 'Postgres Check Api',
  version: '0.0.0',
})
  .addComponent('responses', (o) => ({
    BadRequest: o.response(o.textContent()),
    Unauthorized: o.response(o.textContent()),
    Forbidden: o.response(o.textContent()),
    InternalServerError: o.response(o.textContent()),
  }))
  .addComponent('securitySchemes', (o) => ({
    ApiKey: o.apiKeyScheme('header', 'x-account-api-key'),
  }))
  .defaultResponses((o) => ({
    400: o.responseReference('BadRequest'),
    401: o.responseReference('Unauthorized'),
    403: o.responseReference('Forbidden'),
    500: o.responseReference('InternalServerError'),
  }))
  .add('security', (o) => [{ ApiKey: [] }])
  .add('paths', (o) => ({
    '/monitor': {
      get: {
        operationId: 'getMonitors',
        parameters: [],
        responses: {
          200: o.response(o.jsonContent('MonitorCollection')),
        },
        'x-amazon-apigateway-integration': {
          httpMethod: 'POST',
          payloadFormatVersion: '1.0',
          type: 'aws_proxy',
          uri: '${lambda}',
        },
      },
      post: {
        operationId: 'createMonitor',
        parameters: [],
        requestBody: {
          content: o.jsonContent('Monitor'),
        },
        responses: {
          201: o.response(o.jsonContent('Monitor')),
        },
        'x-amazon-apigateway-integration': {
          httpMethod: 'POST',
          payloadFormatVersion: '1.0',
          type: 'aws_proxy',
          uri: '${lambda}',
        },
      },
    },
    '/monitor/{monitorId}/check': {
      get: {
        operationId: 'getChecks',
        parameters: [
          o.path('monitorId'),
          o.query('created', false),
          o.query('limit', false),
          o.query('next', false),
        ],
        responses: {
          200: o.response(o.jsonContent('CheckCollection')),
        },
        'x-amazon-apigateway-integration': {
          httpMethod: 'POST',
          payloadFormatVersion: '1.0',
          type: 'aws_proxy',
          uri: '${lambda}',
        },
      },
    },
    '/monitor/{monitorId}/check/{checkId}/query': {
      get: {
        operationId: 'getQueries',
        parameters: [
          o.path('monitorId'),
          o.path('checkId'),
          o.query('type'),
          o.query('created', false),
          o.query('limit', false),
          o.query('next', false),
        ],
        responses: {
          200: o.response(o.jsonContent('QueryCollection')),
        },
        'x-amazon-apigateway-integration': {
          httpMethod: 'POST',
          payloadFormatVersion: '1.0',
          type: 'aws_proxy',
          uri: '${lambda}',
        },
      },
    },
  }))
  .add('servers', (o) => [
    { url: 'http://localhost:5001', description: 'local', variables: {} },
    {
      url: 'https://api.dev.postgrescheck.com',
      description: 'dev',
      variables: {},
    },
  ])
  .build();

export default postgresCheckApi;
